@@ -13,14 +13,13 @@ use MIDI::RtController ();
 use MIDI::Simple ();
 use Music::Tempo qw(bpm_to_ms);
 use namespace::clean;
-
 use Exporter qw(import);
 our @EXPORT = qw(
-    get_score
     b
     c
     d
     e
+    g
     i
     n
     o
@@ -32,7 +31,7 @@ our @EXPORT = qw(
     x
 );
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 my $self;
 
@@ -76,10 +75,6 @@ sub END {
     }
 }
 
-sub get_score {
-    return $self->score;
-}
-
 sub b {
     my ($bpm) = @_;
     $self->score->set_tempo(bpm_to_ms($bpm) * 1000);
@@ -98,6 +93,10 @@ sub e {
     $self->play($value);
 }
 
+sub g {
+    return $self->score;
+}
+
 sub i {
     my $rtc = MIDI::RtController->new(input => $_[0], output => $_[1], verbose => 1);
     $rtc->run;
@@ -204,15 +203,15 @@ Play at end
 
 Default: C<1>
 
+=head2 g
+
+Return the L<MIDI::Simple> score object.
+
 =head2 i
 
 Invoke L<MIDI::RtController> to control the second argument with the
 first.
 
-=head2 get_score
-
-Return the L<MIDI::Simple> score object.
-
 =head2 n
 
   n(@note_spec)
@@ -300,7 +299,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2022 by Gene Boggs.
+This software is Copyright (c) 2022-2025 by Gene Boggs.
 
 This is free software, licensed under: The Artistic License 2.0 (GPL Compatible)
 
